@@ -375,11 +375,11 @@ class RedisConnection(AbcConnection):
         while self._pubsub_channels:
             _, ch = self._pubsub_channels.popitem()
             logger.debug("Closing pubsub channel %r", ch)
-            ch.close()
+            ch.close(exc)
         while self._pubsub_patterns:
             _, ch = self._pubsub_patterns.popitem()
             logger.debug("Closing pubsub pattern %r", ch)
-            ch.close()
+            ch.close(exc)
 
     @property
     def closed(self):
@@ -464,6 +464,11 @@ class RedisConnection(AbcConnection):
     def _update_pubsub(self, obj, *, ch):
         kind, *pattern, channel, subscriptions = obj
         self._in_pubsub, was_in_pubsub = subscriptions, self._in_pubsub
+        # XXX: the channels/patterns storage should be refactored.
+        #   if code which supposed to read from channel/pattern
+        #   failed (exception in reader or else) than
+        #   the channel object will still reside in memory
+        #   and leak memory (messages will be put in queue).
         if kind == b'subscribe' and channel not in self._pubsub_channels:
             self._pubsub_channels[channel] = ch
         elif kind == b'psubscribe' and channel not in self._pubsub_patterns:
