@@ -105,6 +105,8 @@ def create_sentinel(_closable, loop):
 
     async def f(*args, **kw):
         kw.setdefault('loop', loop)
+        # make it fail fast on slow CIs (if timeout argument is ommitted)
+        kw.setdefault('timeout', .001)
         client = await aioredis.sentinel.create_sentinel(*args, **kw)
         _closable(client)
         return client
@@ -132,7 +134,7 @@ def redis(create_redis, server, loop):
 def redis_sentinel(create_sentinel, sentinel, loop):
     """Returns Redis Sentinel client instance."""
     redis_sentinel = loop.run_until_complete(
-        create_sentinel([sentinel.tcp_address], loop=loop))
+        create_sentinel([sentinel.tcp_address], timeout=2, loop=loop))
     assert loop.run_until_complete(redis_sentinel.ping()) == b'PONG'
     return redis_sentinel
 
@@ -250,13 +252,6 @@ def format_version(srv):
     return 'redis_v{}'.format('.'.join(map(str, VERSIONS[srv])))
 
 
-@pytest.fixture(scope='session', params=REDIS_SERVERS, ids=format_version)
-def server_bin(request):
-    """Common for start_server and start_sentinel server bin path parameter.
-    """
-    return request.param
-
-
 @pytest.fixture(scope='session')
 def start_server(_proc, request, unused_port, server_bin):
     """Starts Redis server instance.
@@ -564,12 +559,6 @@ def pytest_runtest_setup(item):
         item.fixturenames.append('loop')
 
 
-def pytest_ignore_collect(path, config):
-    if 'py35' in str(path):
-        if sys.version_info < (3, 5, 0):
-            return True
-
-
 def pytest_collection_modifyitems(session, config, items):
     for item in items:
         if 'redis_version' in item.keywords:
@@ -594,6 +583,18 @@ def pytest_configure(config):
     VERSIONS.update({srv: _read_server_version(srv)
                      for srv in REDIS_SERVERS})
     assert VERSIONS, ("Expected to detect redis versions", REDIS_SERVERS)
+
+    class DynamicFixturePlugin:
+        @pytest.fixture(scope='session',
+                        params=REDIS_SERVERS,
+                        ids=format_version)
+        def server_bin(self, request):
+            """Common for start_server and start_sentinel
+            server bin path parameter.
+            """
+            return request.param
+    config.pluginmanager.register(DynamicFixturePlugin(), 'server-bin-fixture')
+
     if config.getoption('--uvloop'):
         try:
             import uvloop
